@@ -22,8 +22,10 @@ NetworkMetadataLowercaseIndex = namedtuple('NetworkMetadataLowercaseIndex',
 class NetworkMetadataClient(PreseemGrpcClient):
 
     def __init__(self, api_key, host=None, port=None, beta=None):
-        super().__init__(api_key, host
-                         or 'nmapi{}.preseem.com'.format('-beta' if beta else ''), port)
+        super().__init__(api_key,
+                         host or 'nmapi{}.preseem.com'.format('-beta' if beta else ''),
+                         port,
+                         compression=True)
 
 
 def ip_sort_key(x):
