@@ -9,7 +9,6 @@ import ipaddress
 import logging
 import os
 import time
-import pkg_resources
 
 import aiohttp
 import aiohttp.web
@@ -445,15 +444,6 @@ def run_tool_script(coroutine):
         loop.close()
 
 
-def check_required_dependency(req_file: str):
-    """Check the current environment have all dependencies required from a given file.
-
-    Args:
-        req_file (str): The file path of the requirement.txt.
-    """
-    pkg_resources.require(open(req_file).read())
-
-
 async def _mikrotik_probe(host,
                           mikrotik_api_cls,
                           creds,
