@@ -262,4 +262,4 @@ class TestConfig(unittest.TestCase):
         self.maxDiff = 10000
         obj = cfgs[0]._asdict()
         obj.pop('id')  # don't compare this, it changes from run to run 
-        self.assertEqual(obj, {'enabled': False, 'extra': None, 'url': '', 'google_id': '', 'delimiter': '', 'fields': {'id': '', 'secondary_id': '', 'account_id': '', 'name': '', 'cpe_mac': '', 'dev_mac': '', 'cpe_ip_address': '', 'ip_address': '', 'kbps_down': '', 'kbps_up': '', 'mbps_down': '', 'mbps_up': '', 'package_name': '', 'sector': '', 'imsi': '', 'ip_address_2': '', 'serial_number': '', 'account_status': ''}, 'header': [], 'poll_interval': 0, 'system': '', 'service_rate_multiplier': 0.0, 'account_status_config': {'OFFLINE': {'account_status': 'DELINQUENT', 'kbps_down': '1', 'kbps_up': '1'}}})
+        self.assertEqual(obj, {'enabled': False, 'extra': None, 'url': '', 'google_id': '', 'delimiter': '', 'fields': {'id': '', 'secondary_id': '', 'account_id': '', 'name': '', 'cpe_mac': '', 'dev_mac': '', 'cpe_ip_address': '', 'ip_address': '', 'kbps_down': '', 'kbps_up': '', 'mbps_down': '', 'mbps_up': '', 'package_name': '', 'sector': '', 'imsi': '', 'ip_address_2': '', 'serial_number': '', 'account_status': ''}, 'header': [], 'poll_interval': 0, 'system': '', 'service_rate_multiplier': 0.0, 'account_status_config': {'OFFLINE': {'account_status': 'DELINQUENT', 'kbps_down': 1, 'kbps_up': 1}}})
