@@ -660,3 +660,207 @@ class TestIntervalStats(unittest.TestCase):
         i1 = msg.data.interfaces[0]
         i1.in_octets = 417801806432
         new_msg = self.mgr.handle_message(msg)
+
+    def test_interval_stats_08(self):
+        """PPA-1575 changes in counter source are handled correctly."""
+        company_uuid = uuid4().bytes
+        msg = NetworkElementUpdate()
+        msg.company_uuid = company_uuid
+        msg.instance = 'test-interval-stats'
+        msg.active = msg.pingable = True
+        msg.data.management_ip = "10.16.19.2"
+        msg.data.name = 'br-merom_segrain.water.gville'
+        msg.data.system_mac_address = 'bc:e6:7c:20:09:0b'
+        msg.data.poller_hash = _make_poller_hash(company_uuid, msg.data.system_mac_address)
+        msg.data.counter_source = 'source1'
+        i1 = msg.data.interfaces.add()
+        i1.mac_address = 'bc:e6:7c:20:09:0b'
+        tmsg = msg
+
+        msg.time.FromSeconds(1638374073) # 15:54:33
+        i1.in_octets = 417705082908
+        new_msg = self.mgr.handle_message(msg)
+        self.assertIsNone(new_msg)
+
+        msg = NetworkElementUpdate()
+        msg.CopyFrom(tmsg)
+        msg.time.FromSeconds(msg.time.seconds + 60)
+        i1 = msg.data.interfaces[0]
+        i1.in_octets += 60000
+        new_msg = self.mgr.handle_message(msg)
+        self.assertIsNotNone(new_msg)
+        self.assertFalse(new_msg.data.interfaces[0].HasField('in_octets'))
+
+        msg = NetworkElementUpdate()
+        msg.CopyFrom(tmsg)
+        msg.time.FromSeconds(msg.time.seconds + 120)
+        i1 = msg.data.interfaces[0]
+        i1.in_octets += 180000
+        new_msg = self.mgr.handle_message(msg)
+        self.assertEqual(new_msg.data.interfaces[0].in_octets, 87000)
+
+        # Now that we have the state going, send a message with a different counter
+        # source and verify that we get no counters for the overlapping intervals.
+        msg = NetworkElementUpdate()
+        msg.CopyFrom(tmsg)
+        msg.data.counter_source = 'source2'
+        msg.time.FromSeconds(msg.time.seconds + 180)
+        i1 = msg.data.interfaces[0]
+        i1.in_octets += 240000
+        new_msg = self.mgr.handle_message(msg)
+        self.assertFalse(new_msg.data.interfaces[0].HasField('in_octets'))
+
+        msg = NetworkElementUpdate()
+        msg.CopyFrom(tmsg)
+        msg.data.counter_source = 'source2'
+        msg.time.FromSeconds(msg.time.seconds + 240)
+        i1 = msg.data.interfaces[0]
+        i1.in_octets += 300000
+        new_msg = self.mgr.handle_message(msg)
+        self.assertFalse(new_msg.data.interfaces[0].HasField('in_octets'))
+
+        msg = NetworkElementUpdate()
+        msg.CopyFrom(tmsg)
+        msg.data.counter_source = 'source2'
+        msg.time.FromSeconds(msg.time.seconds + 300)
+        i1 = msg.data.interfaces[0]
+        i1.in_octets += 360000
+        new_msg = self.mgr.handle_message(msg)
+        self.assertEqual(new_msg.data.interfaces[0].in_octets, 60000)
+
+    def test_interval_stats_09(self):
+        """PPA-1575 changes in peer counter source are handled correctly."""
+        company_uuid = uuid4().bytes
+        msg = NetworkElementUpdate()
+        msg.company_uuid = company_uuid
+        msg.instance = 'test-interval-stats'
+        msg.active = msg.pingable = True
+        msg.data.management_ip = "10.16.19.2"
+        msg.data.name = 'br-merom_segrain.water.gville'
+        msg.data.system_mac_address = 'bc:e6:7c:20:09:0b'
+        msg.data.poller_hash = _make_poller_hash(company_uuid, msg.data.system_mac_address)
+        i1 = msg.data.interfaces.add()
+        i1.name = 'ap_wlan'
+        i1.mac_address = 'bc:e6:7c:20:09:0c'
+        i1.poller_hash = _make_poller_hash(company_uuid, 'bc:e6:7c:20:09:0c')
+        peer = msg.peers.add()
+        peer.poller_hash = _make_poller_hash(company_uuid, '00:01:02:03:04:05')
+        peer.counter_source = 'source1'
+        i2 = peer.interfaces.add()
+        i2.name = 'sta_wlan'
+        i2.poller_hash = _make_poller_hash(company_uuid, '00:01:02:03:04:06')
+        l1 = i1.links.add()
+        l1.poller_hash = i2.poller_hash
+        l2 = i2.links.add()
+        l2.poller_hash = i1.poller_hash
+
+        tmsg = msg
+
+        msg.time.FromSeconds(1638374073) # 15:54:33
+        i1.in_octets = 100000
+        i2.in_octets = 200000
+        l1.in_octets = l2.out_octets = i1.in_octets
+        l2.in_octets = l1.out_octets = i2.in_octets
+        new_msg = self.mgr.handle_message(msg)
+        self.assertIsNone(new_msg)
+
+        msg = NetworkElementUpdate()
+        msg.CopyFrom(tmsg)
+        msg.time.FromSeconds(msg.time.seconds + 60)
+        i1 = msg.data.interfaces[0]
+        i1.in_octets += 60000
+        i2 = msg.peers[0].interfaces[0]
+        i2.in_octets += 60000
+        l1 = msg.data.interfaces[0].links[0]
+        l2 = msg.peers[0].interfaces[0].links[0]
+        l1.in_octets = l2.out_octets = i1.in_octets
+        l2.in_octets = l1.out_octets = i2.in_octets
+        new_msg = self.mgr.handle_message(msg)
+        self.assertIsNotNone(new_msg)
+        self.assertFalse(new_msg.data.interfaces[0].HasField('in_octets'))
+        self.assertFalse(new_msg.data.interfaces[0].links[0].HasField('in_octets'))
+        self.assertFalse(new_msg.data.interfaces[0].links[0].HasField('out_octets'))
+        self.assertFalse(new_msg.peers[0].interfaces[0].HasField('in_octets'))
+        self.assertFalse(new_msg.peers[0].interfaces[0].links[0].HasField('in_octets'))
+        self.assertFalse(new_msg.peers[0].interfaces[0].links[0].HasField('out_octets'))
+
+        msg = NetworkElementUpdate()
+        msg.CopyFrom(tmsg)
+        msg.time.FromSeconds(msg.time.seconds + 120)
+        i1 = msg.data.interfaces[0]
+        i1.in_octets += 120000
+        i2 = msg.peers[0].interfaces[0]
+        i2.in_octets += 120000
+        l1 = msg.data.interfaces[0].links[0]
+        l2 = msg.peers[0].interfaces[0].links[0]
+        l1.in_octets = l2.out_octets = i1.in_octets
+        l2.in_octets = l1.out_octets = i2.in_octets
+        new_msg = self.mgr.handle_message(msg)
+        self.assertEqual(new_msg.data.interfaces[0].in_octets, 60000)
+        self.assertEqual(new_msg.data.interfaces[0].links[0].in_octets, 60000)
+        self.assertEqual(new_msg.data.interfaces[0].links[0].out_octets, 60000)
+        self.assertEqual(new_msg.peers[0].interfaces[0].in_octets, 60000)
+        self.assertEqual(new_msg.peers[0].interfaces[0].links[0].in_octets, 60000)
+        self.assertEqual(new_msg.peers[0].interfaces[0].links[0].out_octets, 60000)
+
+        # Now that we have the state going, send a message with a different counter
+        # source and verify that we get no counters for the overlapping intervals.
+        msg = NetworkElementUpdate()
+        msg.CopyFrom(tmsg)
+        msg.peers[0].counter_source = 'source2'
+        msg.time.FromSeconds(msg.time.seconds + 180)
+        i1 = msg.data.interfaces[0]
+        i1.in_octets += 180000
+        i2 = msg.peers[0].interfaces[0]
+        i2.in_octets += 180000
+        l1 = msg.data.interfaces[0].links[0]
+        l2 = msg.peers[0].interfaces[0].links[0]
+        l1.in_octets = l2.out_octets = i1.in_octets
+        l2.in_octets = l1.out_octets = i2.in_octets
+        new_msg = self.mgr.handle_message(msg)
+        self.assertEqual(new_msg.data.interfaces[0].in_octets, 60000)
+        self.assertFalse(new_msg.data.interfaces[0].links[0].HasField('in_octets'))
+        self.assertFalse(new_msg.data.interfaces[0].links[0].HasField('out_octets'))
+        self.assertFalse(new_msg.peers[0].interfaces[0].HasField('in_octets'))
+        self.assertFalse(new_msg.peers[0].interfaces[0].links[0].HasField('in_octets'))
+        self.assertFalse(new_msg.peers[0].interfaces[0].links[0].HasField('out_octets'))
+
+        msg = NetworkElementUpdate()
+        msg.CopyFrom(tmsg)
+        msg.peers[0].counter_source = 'source2'
+        msg.time.FromSeconds(msg.time.seconds + 240)
+        i1 = msg.data.interfaces[0]
+        i1.in_octets += 240000
+        i2 = msg.peers[0].interfaces[0]
+        i2.in_octets += 240000
+        l1 = msg.data.interfaces[0].links[0]
+        l2 = msg.peers[0].interfaces[0].links[0]
+        l1.in_octets = l2.out_octets = i1.in_octets
+        l2.in_octets = l1.out_octets = i2.in_octets
+        new_msg = self.mgr.handle_message(msg)
+        self.assertEqual(new_msg.data.interfaces[0].in_octets, 60000)
+        self.assertFalse(new_msg.data.interfaces[0].links[0].HasField('in_octets'))
+        self.assertFalse(new_msg.data.interfaces[0].links[0].HasField('out_octets'))
+        self.assertFalse(new_msg.peers[0].interfaces[0].HasField('in_octets'))
+        self.assertFalse(new_msg.peers[0].interfaces[0].links[0].HasField('in_octets'))
+        self.assertFalse(new_msg.peers[0].interfaces[0].links[0].HasField('out_octets'))
+
+        msg = NetworkElementUpdate()
+        msg.CopyFrom(tmsg)
+        msg.peers[0].counter_source = 'source2'
+        msg.time.FromSeconds(msg.time.seconds + 300)
+        i1 = msg.data.interfaces[0]
+        i1.in_octets += 300000
+        i2 = msg.peers[0].interfaces[0]
+        i2.in_octets += 300000
+        l1 = msg.data.interfaces[0].links[0]
+        l2 = msg.peers[0].interfaces[0].links[0]
+        l1.in_octets = l2.out_octets = i1.in_octets
+        l2.in_octets = l1.out_octets = i2.in_octets
+        new_msg = self.mgr.handle_message(msg)
+        self.assertEqual(new_msg.data.interfaces[0].in_octets, 60000)
+        self.assertEqual(new_msg.data.interfaces[0].links[0].in_octets, 60000)
+        self.assertEqual(new_msg.data.interfaces[0].links[0].out_octets, 60000)
+        self.assertEqual(new_msg.peers[0].interfaces[0].in_octets, 60000)
+        self.assertEqual(new_msg.peers[0].interfaces[0].links[0].in_octets, 60000)
+        self.assertEqual(new_msg.peers[0].interfaces[0].links[0].out_octets, 60000)
